==> dumbpainttool-0.39a122.tar.gz: dumbpainttool-0.39a122/README.md <==
![Linux](https://img.shields.io/badge/-Linux-grey?logo=linux)
![Usage](https://img.shields.io/badge/Usage-Terminal%20User%20Interface-yellow)
![Python](https://img.shields.io/badge/Python-v3.9%5E-green?logo=python)
![pyTermTk_version](https://img.shields.io/github/v/tag/ceccopierangiolieugenio/pyTermTk?label=version)
[![Test Status](https://img.shields.io/github/actions/workflow/status/ceccopierangiolieugenio/pyTermTk/testing.yml?branch=main&label=tests)](https://github.com/ceccopierangiolieugenio/pyTermTk/actions?query=workflow%3Atesting)
[![pypi_version](https://img.shields.io/pypi/v/ttkDesigner?label=pypi)](https://pypi.org/project/dumbPaintTool)
[![pypi_version](https://img.shields.io/twitter/follow/Pier95886803?style=social&logo=twitter)](https://twitter.com/hashtag/pyTermTk?src=hashtag_click&f=live)


[![dpt hero](https://github.com/ceccopierangiolieugenio/pyTermTk/assets/8876552/54d29d95-717d-404d-9112-efed866d4048)](https://pypi.org/project/dumbPaintTool)


## [the Dumb Paint Tool](https://github.com/ceccopierangiolieugenio/pyTermTk/tree/main/tools/dumbPaintTool)

A Uber SourcesOpen Super Duper Powerful and User-Friendly ASCII/ANSI/UTF-8  Terminal art editor, basically the Terminal ASCII Photoshop


#### Features
* Pure Terminal App (it run on [xterm](https://en.wikipedia.org/wiki/Xterm) or [Terminator](https://en.wikipedia.org/wiki/GNOME_Terminator) or [MacOS Terminal](https://support.apple.com/en-gb/guide/terminal/welcome/mac) or [Windows Terminal](https://github.com/microsoft/terminal) or . . .)
* Did I mention it is a Terminal App? You can run it via SSH, Telnet or Serial
* Wide variety of glyphs (UTF-8)
* Wide Variety of tools
* Copy and Paste from the terminal or the web app
* Drag files to be open (WebVersion Only)
* Imkage/Pictures import with configurable ASCII rasterizers
* Layers
* Intelligent Transparent Layers
* Beautiful Dumb Transparent Layers
* ANSI/ASCII Export
* And more to come . . .

#### Used in:
[A Snake🐍 on a Plane✈️ - The Roguelike](https://ceccopierangiolieugenio.itch.io/a-snake-on-a-plane)

#### This farting beauty is due to:
[pyTermTk](https://github.com/ceccopierangiolieugenio/pyTermTk) a magical mesmerising  Python TUI library

## Installation

Try it live on [itch.io](https://ceccopierangiolieugenio.itch.io/dumb-paint-tool)

or install it from [pypi](https://pypi.org/project/dumbPaintTool):

```bash
pip install dumbPaintTool --upgrade

dumbPaintTool
```

==> dumbpainttool-0.41.8a54.tar.gz: dumbpainttool-0.41.8a54/README.md <==
![Linux](https://img.shields.io/badge/-Linux-grey?logo=linux)
![Usage](https://img.shields.io/badge/Usage-Terminal%20User%20Interface-yellow)
![Python](https://img.shields.io/badge/Python-v3.9%5E-green?logo=python)
![pyTermTk_version](https://img.shields.io/github/v/tag/ceccopierangiolieugenio/pyTermTk?label=version)
[![Test Status](https://img.shields.io/github/actions/workflow/status/ceccopierangiolieugenio/pyTermTk/testing.yml?branch=main&label=tests)](https://github.com/ceccopierangiolieugenio/pyTermTk/actions?query=workflow%3Atesting)
[![pypi_version](https://img.shields.io/pypi/v/ttkDesigner?label=pypi)](https://pypi.org/project/dumbPaintTool)
[![pypi_version](https://img.shields.io/twitter/follow/Pier95886803?style=social&logo=twitter)](https://twitter.com/hashtag/pyTermTk?src=hashtag_click&f=live)


![dpt hero](https://github.com/ceccopierangiolieugenio/pyTermTk/assets/8876552/005b31a9-d9d6-4799-be17-5a3e478a4703)


## [the Dumb Paint Tool](https://github.com/ceccopierangiolieugenio/pyTermTk/tree/main/apps/dumbPaintTool)

A Uber SourcesOpen Super Duper Powerful and User-Friendly ASCII/ANSI/UTF-8  Terminal art editor, basically the Terminal ASCII Photoshop


#### Features
* Pure Terminal App (it runs on [xterm](https://en.wikipedia.org/wiki/Xterm) or [Terminator](https://en.wikipedia.org/wiki/GNOME_Terminator) or [MacOS Terminal](https://support.apple.com/en-gb/guide/terminal/welcome/mac) or [Windows Terminal](https://github.com/microsoft/terminal) or . . .)
* Did I mention it is a Terminal App? You can run it via SSH, Telnet or Serial
* Wide variety of glyphs (UTF-8)
* Wide Variety of tools
* Copy and Paste from the terminal or the web app
* Drag files to be open ([WebVersion](https://ceccopierangiolieugenio.itch.io/dumb-paint-tool) Only)
* Image/Pictures import with configurable ASCII rasterizers
* Layers
* Intelligent Transparent Layers
* Beautiful Dumb Transparent Layers
* ANSI/ASCII Export
* **Unlimited** Undo/Redo

* And more to come . . .

#### Used in:
[A Snake🐍 on a Plane✈️ - The Roguelike](https://ceccopierangiolieugenio.itch.io/a-snake-on-a-plane)

#### This farting beauty is due to:
[pyTermTk](https://github.com/ceccopierangiolieugenio/pyTermTk) a magical mesmerising  Python TUI library

## Installation

Try it live on [itch.io](https://ceccopierangiolieugenio.itch.io/dumb-paint-tool)

or install it from [pypi](https://pypi.org/project/dumbPaintTool):

```bash
pip install dumbPaintTool --upgrade

dumbPaintTool
```
